===================================================================
RCS file: /home/cvs/OpenXM_contrib/gmp/mpn/i960/Attic/add_n.s,v
retrieving revision 1.1
retrieving revision 1.1.1.3
diff -u -p -r1.1 -r1.1.1.3
--- OpenXM_contrib/gmp/mpn/i960/Attic/add_n.s	2000/01/10 15:35:24	1.1
+++ OpenXM_contrib/gmp/mpn/i960/Attic/add_n.s	2003/08/25 16:06:21	1.1.1.3
@@ -1,29 +1,29 @@
 # I960 __mpn_add_n -- Add two limb vectors of the same length > 0 and store
 # sum in a third limb vector.
 
-# Copyright (C) 1995 Free Software Foundation, Inc.
+# Copyright 1995, 2000 Free Software Foundation, Inc.
 
 # This file is part of the GNU MP Library.
 
 # The GNU MP Library is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Library General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or (at your
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation; either version 2.1 of the License, or (at your
 # option) any later version.
 
 # The GNU MP Library is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
+# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 # License for more details.
 
-# You should have received a copy of the GNU Library General Public License
+# You should have received a copy of the GNU Lesser General Public License
 # along with the GNU MP Library; see the file COPYING.LIB.  If not, write to
 # the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 # MA 02111-1307, USA.
 
 .text
 	.align 4
-	.globl ___mpn_add_n
-___mpn_add_n:
+	.globl ___gmpn_add_n
+___gmpn_add_n:
 	mov	0,g6		# clear carry-save register
 	cmpo	1,0		# clear cy
@@ -1,29 +1,29 @@
-# I960 __mpn_add_n -- Add two limb vectors of the same length > 0 and store
+# I960 __gmpn_add_n -- Add two limb vectors of the same length > 0 and store
 # sum in a third limb vector.
 